@@ -1,4 +1,4 @@
-use crate::Linkage;
+use crate::{Formula, Linkage, Mechanism, Point as _};
 use std::{
     f64::consts::FRAC_PI_6,
     ops::{Div, DivAssign},
@@ -131,6 +131,61 @@ impl FourBar {
 
 impl Linkage for FourBar {
     type Joint = [[f64; 2]; 5];
+
+    fn allocate(&self) -> (Self::Joint, Vec<crate::mechanism::Formula>) {
+        let Self {
+            p0,
+            a,
+            l0,
+            l1,
+            l2,
+            l3,
+            l4,
+            g,
+            inv,
+        } = self;
+        let joints = [
+            [p0.x(), p0.y()],
+            [p0.x() + l0 * a.cos(), p0.y() + l0 * a.sin()],
+            [0., 0.],
+            [0., 0.],
+            [0., 0.],
+        ];
+        let mut fs = Vec::with_capacity(3);
+        fs.push(Formula::Pla(0, *l1, 0., 2));
+        if (l0 - l2).abs() < 1e-20 && (l1 - l3).abs() < 1e-20 {
+            // Special case
+            fs.push(Formula::Ppp(0, 2, 1, 3));
+        } else {
+            fs.push(Formula::Pllp(2, *l2, *l3, 1, *inv, 3));
+        }
+        fs.push(Formula::Plap(2, *l4, *g, 3, 4));
+        (joints, fs)
+    }
+
+    fn apply<const N: usize>(
+        m: &Mechanism<Self>,
+        angle: f64,
+        joint: [usize; N],
+        ans: &mut [[f64; 2]; N],
+    ) {
+        let mut joints = m.joints;
+        let mut formulas = m.fs.clone();
+        match formulas.first_mut() {
+            Some(Formula::Pla(_, _, ref mut a, _)) => *a = angle,
+            _ => panic!("invalid four bar"),
+        }
+        for f in formulas {
+            f.apply(&mut joints);
+        }
+        if joints[4][0].is_nan() || joints[4][1].is_nan() {
+            ans.clone_from(&[[f64::NAN; 2]; N]);
+        } else {
+            for (ans, joint) in ans.iter_mut().zip(joint) {
+                ans.clone_from(&joints[joint]);
+            }
+        }
+    }
 }
 
 impl Div<f64> for FourBar {
